@@ -31,17 +31,11 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gio/gio.h>
-#include <libmate-desktop/mate-aboutdialog.h>
 #include <mate-panel-applet.h>
 
 #include "trash-empty.h"
 #include "xstuff.h"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
-
 typedef MatePanelAppletClass TrashAppletClass;
 
 typedef struct
@@ -420,15 +414,20 @@ trash_applet_show_about (GtkAction   *action,
     "Ryan Lortie <desrt@desrt.ca>",
     NULL
   };
+
+  char copyright[] = \
+    "Copyright \xc2\xa9 2012-2016 MATE developers\n"
+    "Copyright \xc2\xa9 2008 Ryan Lortie\n"
+    "Copyright \xc2\xa9 2004 Michiel Sikkes";
+
   static const char *documenters[] = {
     "Michiel Sikkes <michiel@eyesopened.nl>",
     NULL
   };
 
-  mate_show_about_dialog (NULL,
+  gtk_show_about_dialog (NULL,
                          "version", VERSION,
-                         "copyright", "Copyright \xC2\xA9 2004 Michiel Sikkes,"
-                                      "\xC2\xA9 2008 Ryan Lortie",
+                         "copyright", copyright,
                          "comments", _("A MATE trash bin that lives in your panel. "
                                        "You can use it to view the trash or drag "
                                        "and drop items into the trash."),
@@ -465,7 +464,7 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 14);
 
-  hbox = gtk_hbox_new (FALSE, 12);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   gtk_widget_show (hbox);
   gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), hbox,
@@ -473,16 +472,12 @@ confirm_delete_immediately (GtkWidget *parent_view,
 
   image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION,
                                     GTK_ICON_SIZE_DIALOG);
-#if GTK_CHECK_VERSION (3, 0, 0)
   gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
   gtk_widget_set_valign (image, GTK_ALIGN_START);
-#else
-  gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-#endif
   gtk_widget_show (image);
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-  vbox = gtk_vbox_new (FALSE, 12);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
   gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
   gtk_widget_show (vbox);
 
